ALTER TABLE tab1 ADD CONSTRAINT foo FOREIGN KEY (id1) REFERENCES tab2 (id2) DEFERRABLE INITIALLY DEFERRED
=
ALTER TABLE tab1 ADD CONSTRAINT foo FOREIGN KEY (id1) REFERENCES tab2 (id2) DEFERRABLE INITIALLY DEFERRED

ALTER TABLE color ALTER COLUMN color_id ADD GENERATED BY DEFAULT AS IDENTITY
=
ALTER TABLE color ALTER COLUMN color_id ADD GENERATED BY DEFAULT AS IDENTITY;
:
{'semicolon_after_last_statement': True}

ALTER TABLE books
ADD CONSTRAINT distfk
FOREIGN KEY (author_id) REFERENCES authors (author_id) ON UPDATE RESTRICT NOT VALID
=
ALTER TABLE books ADD CONSTRAINT distfk FOREIGN KEY (author_id) REFERENCES authors (author_id) ON UPDATE RESTRICT NOT VALID;
:
{'semicolon_after_last_statement': True}
